@@ -74,40 +74,19 @@ class BuildClass(_base.BaseValue):
       # We have hit 'maximum depth' before setting func.last_frame
       func.f_locals = self.ctx.convert.unsolvable
       class_closure_var = None
-    clsvar = None
-    for base in bases:
-      base = abstract_utils.get_atomic_value(
-          base, default=self.ctx.convert.unsolvable)
-      cls_dict = func.f_locals.to_variable(node)
-      # Every subclass of an enum is itself an enum. To properly process them,
-      # the class must be built by the enum overlay.
-      if (isinstance(base, class_mixin.Class) and base.is_enum and
-          self.ctx.options.use_enum_overlay):
-        enum_base = abstract_utils.get_atomic_value(
-            self.ctx.vm.loaded_overlays["enum"].members["Enum"])
-        node, clsvar = enum_base.make_class(
-            node, name, list(bases), cls_dict, metaclass,
-            new_class_var=class_closure_var, is_decorated=self.is_decorated)
-        break
-      if isinstance(base, PyTDClass):
-        # Subclasses of these classes define their own class constructors.
-        if base.full_name == "typing.NamedTuple":
-          node, clsvar = base.make_class(node, list(bases), cls_dict)
-          break
-        elif base.is_typed_dict_class:
-          node, clsvar = base.make_class(
-              node, list(bases), cls_dict, total=kwargs.get("total"))
-          break
 
+    props = class_mixin.ClassBuilderProperties(
+        name_var=name,
+        bases=list(bases),
+        class_dict_var=func.f_locals.to_variable(node),
+        metaclass_var=metaclass,
+        new_class_var=class_closure_var,
+        is_decorated=self.is_decorated)
+    # Check for special classes first.
+    node, clsvar = _special_classes.build_class(node, props, kwargs, self.ctx)
     if not clsvar:
-      node, clsvar = self.ctx.make_class(
-          node,
-          name,
-          list(bases),
-          func.f_locals.to_variable(node),
-          metaclass,
-          new_class_var=class_closure_var,
-          is_decorated=self.is_decorated)
+      node, clsvar = self.ctx.make_class(node, props)
+
     if self.ctx.options.trace_all_classes:
       self.ctx.vm.trace_classdef(clsvar)
     return node, clsvar
@@ -461,7 +440,7 @@ class PyTDClass(
                                            e.type_param_name)
       self.members[name] = self.ctx.new_unsolvable(self.ctx.root_node)
 
-  def _convert_member(self, member, subst=None):
+  def _convert_member(self, name, member, subst=None):
     """Convert a member as a variable. For lazy lookup."""
     subst = subst or datatypes.AliasingDict()
     node = self.ctx.root_node
@@ -518,7 +497,7 @@ class PyTDClass(
     c = self.pytd_cls.Lookup(name)
     if isinstance(c, pytd.Constant):
       try:
-        self._convert_member(c)
+        self._convert_member(name, c)
       except self.ctx.convert.TypeParameterError:
         # Constant c cannot be converted without type parameter substitutions,
         # so it must be an instance attribute.
@@ -527,7 +506,7 @@ class PyTDClass(
           subst[itm.full_name] = self.ctx.convert.constant_to_value(
               itm.type_param, {}).instantiate(
                   self.ctx.root_node, container=instance)
-        return self._convert_member(c, subst)
+        return self._convert_member(name, c, subst)
 
   def generate_ast(self):
     """Generate this class's AST, including updated members."""
