@@ -300,10 +300,13 @@ class _ParseVisitor(libcst.CSTVisitor):
     keys_to_absorb = []
     keys_to_move = []
     for line_range in reversed(self.structured_comment_groups):
-      if (cls is type(line_range) is _LineRange and
+      if (cls is _LineRange and
           start_line <= line_range.start_line and
           line_range.end_line <= end_line):
-        keys_to_absorb.append(line_range)
+        if type(line_range) is _LineRange:  # pylint: disable=unidiomatic-typecheck
+          keys_to_absorb.append(line_range)
+        else:
+          keys_to_move.append(line_range)
       elif line_range.start_line > start_line:
         keys_to_move.append(line_range)
       else:
@@ -656,6 +659,11 @@ class Director:
           else:
             final_line = self._adjust_line_number_for_pytype_directive(
                 line, error_name, line_range, opcode_lines)
+            if final_line != line:
+              # Set the disable on the original line so that, even if we mess up
+              # adjusting the line number, silencing an error by adding a
+              # disable to the exact line the error is reported on always works.
+              lines.set_line(line, disable)
             lines.set_line(final_line, disable)
         else:
           self._errorlog.invalid_directive(
