@@ -9,15 +9,7 @@ class TypingExtensionsOverlay(overlay.Overlay):
   def __init__(self, ctx):
     ast = ctx.loader.import_name("typing_extensions")
     member_map = {
-        "Annotated": typing_overlay.typing_overlay["Annotated"],
-        "final": typing_overlay.typing_overlay["final"],
-        "Final": typing_overlay.typing_overlay["Final"],
-        "Literal": typing_overlay.typing_overlay["Literal"],
-        "Protocol": _build("typing.Protocol"),
         "runtime": _build("typing.runtime_checkable"),
-        "SupportsIndex": _build("typing_extensions.SupportsIndex", ast),
-        "TypeAlias": _build("typing.TypeAlias"),
-        "TypedDict": typing_overlay.typing_overlay["TypedDict"],
     }
     for pyval in ast.aliases + ast.classes + ast.constants + ast.functions:
       # Any public typing_extensions members that are not explicitly implemented
@@ -25,13 +17,16 @@ class TypingExtensionsOverlay(overlay.Overlay):
       _, name = pyval.name.rsplit(".", 1)
       if name.startswith("_"):
         continue
-      if f"typing.{name}" not in ctx.loader.typing:
-        if name not in member_map:
-          member_map[name] = _build_not_supported_yet(name, ast)
+      if name in typing_overlay.typing_overlay:
+        member_map[name] = typing_overlay.typing_overlay[name][0]
+      elif f"typing.{name}" in ctx.loader.typing:
+        member_map[name] = _build(f"typing.{name}")
+      elif name not in member_map:
+        member_map[name] = _build_not_supported_yet(name, ast)
     super().__init__(ctx, "typing_extensions", member_map, ast)
 
-  def _convert_member(self, member, subst=None):
-    var = super()._convert_member(member, subst)
+  def _convert_member(self, name, member, subst=None):
+    var = super()._convert_member(name, member, subst)
     for val in var.data:
       # typing_extensions backports typing features to older versions.
       # Pretending that the backports are in typing is easier than remembering
@@ -41,9 +36,9 @@ class TypingExtensionsOverlay(overlay.Overlay):
     return var
 
 
-def _build(name, ast=None):
-  return lambda ctx: ctx.convert.name_to_value(name, ast=ast)
+def _build(name):
+  return lambda ctx: ctx.convert.name_to_value(name)
 
 
 def _build_not_supported_yet(name, ast):
-  return lambda ctx: typing_overlay.not_supported_yet(name, ctx, ast)
+  return lambda ctx: typing_overlay.not_supported_yet(name, ctx, ast=ast)
