@@ -565,9 +565,6 @@ class QuotedTypeTest(parser_test_base.ParserTestBase):
       def f(x: int) -> str: ...
     """)
 
-  def test_subscript(self):
-    self.check_error("x: List['int']", 1, "List['int'] not supported")
-
 
 class HomogeneousTypeTest(parser_test_base.ParserTestBase):
 
@@ -1351,9 +1348,13 @@ class ClassTest(parser_test_base.ParserTestBase):
     self.check_error("""
       class Foo(badkeyword=Meta): ...
       """, 1, "Unexpected classdef kwarg 'badkeyword'")
+    if sys.version_info[:2] >= (3, 10):
+      expected_msg = "expected ':'"
+    else:
+      expected_msg = "positional argument follows keyword argument"
     self.check_error("""
       class Foo(metaclass=Meta, Bar): ...
-      """, 1, "positional argument follows keyword argument")
+      """, 1, expected_msg)
 
   def test_shadow_pep484(self):
     self.check("""
@@ -2404,21 +2405,12 @@ class LiteralTest(parser_test_base.ParserTestBase):
     """, "x: None")
 
   def test_enum(self):
-    # TODO(b/173742489): support enums.
     self.check("""
       import enum
       from typing import Literal
 
       x: Literal[Color.RED]
 
-      class Color(enum.Enum):
-          RED: str
-    """, """
-      import enum
-      from typing import Any
-
-      x: Any
-
       class Color(enum.Enum):
           RED: str
     """)
@@ -2491,6 +2483,25 @@ class LiteralTest(parser_test_base.ParserTestBase):
       x: Literal[0.0]
     """, 2, "Invalid type `float` in Literal[0.0].")
 
+  def test_forbid_expressions(self):
+    msg = "Expressions are not allowed in typing.Literal."
+    self.check_error("""
+      from typing import Literal
+      x: Literal[3+4]
+    """, 2, msg)
+    self.check_error("""
+      from typing_extensions import Literal
+      x: Literal[3+4]
+    """, 2, msg)
+    self.check_error("""
+      import typing
+      x: typing.Literal[3+4]
+    """, 2, msg)
+    self.check_error("""
+      import typing_extensions
+      x: typing_extensions.Literal[3+4]
+    """, 2, msg)
+
   def test_final_literals(self):
     # See https://github.com/python/typeshed/issues/7258 for context.
     self.check("""
